<?php
if (!class_exists('WPContentMagic_Miscellaneous')) {
	class WPContentMagic_Miscellaneous
	{
		/**
		 * 
		 * Get the first sentence in a text
		 * 
		 * Valid for the follow examples:
		 * - 'A simple test without a character to end the sentence'
		 * - 'This is a sentence with a price $ 7.50 and ends with exclamation! This sentence will not shown.'
		 * - 'This sentence will end with the follow dots .... This sentence will not shown!'
		 * 
		 * @param 	string $string
		 * @return	string
		 */
		static function get_first_sentence($string) {
			return preg_replace('/(.*?[?!.](?=\s|$)).*/', '\\1', $string);
		}

		/**
		 * 
		 * Check if string ends with some letters
		 * 
		 * @param 	string $string
		 * @param 	string $ends_to_test
		 * @return	string
		 */
		static function endswith($string, $ends_to_test) {
		    $strlen = strlen($string);
		    $testlen = strlen($ends_to_test);
		    if ($testlen > $strlen) return false;
		    return substr_compare($string, $ends_to_test, -$testlen) === 0;
		}
		
		
		/**
		 * 
		 * Function to depluralize the words in a phrase
		 * 
		 * @param 	string $words_phrase
		 * @return	string
		 */
		static function depluralize_words_in_phrase($words_phrase){
		    // Here is the list of rules. To add a scenario,
		    // Add the plural ending as the key and the singular
		    // ending as the value for that key. This could be
		    // turned into a preg_replace and probably will be
		    // eventually, but for now, this is what it is.
		    //
		    // Note: The first rule has a value of false since
		    // we don't want to mess with words that end with
		    // double 's'. We normally wouldn't have to create
		    // rules for words we don't want to mess with, but
		    // the last rule (s) would catch double (ss) words
		    // if we didn't stop before it got to that rule. 
		    $rules = array( 
		        'ss' => false, 
		        'os' => 'o', 
		        'ies' => 'y', 
		        'xes' => 'x', 
		        'oes' => 'o', 
		        'ies' => 'y', 
		        'ves' => 'f', 
		        's' => '');
		    
		    $words_arr = explode(' ',$words_phrase);
		    $depluralize_words_arr = array();
		    foreach ($words_arr as $word) {
		    	// Loop through all the rules and do the replacement. 
			    foreach(array_keys($rules) as $key){
			        // If the end of the word doesn't match the key,
			        // it's not a candidate for replacement. Move on
			        // to the next plural ending. 
			        if(substr($word, (strlen($key) * -1)) != $key) {
			        	$new_word = $word;
			            continue;
			        }
			        // If the value of the key is false, stop looping
			        // and return the original version of the word. 
			        if($key === false) {
			            $new_word = $word;
			            break;
			        }
			        // We've made it this far, so we can do the
			        // replacement. 
			        $new_word = substr($word, 0, strlen($word) - strlen($key)) . $rules[$key]; 
			    }
			    
			    $depluralize_words_arr[] = $new_word;
		    }
		    
		    return implode(' ',$depluralize_words_arr);
		}

		/**
         * Return all the parameters by GEt in current page URL
         *
         * @static
         * @param 	string	$param_except	is defined, exclude this parameter
         * @return 	array
         */
		static function get_parameters_by_get($param_except='') {
			$query_parameters = array();
			
			if ($_SERVER['QUERY_STRING']!='') {
				$query_arr = explode('&',$_SERVER['QUERY_STRING']);
				foreach ($query_arr as $query_item) {
					$query_item_arr = explode('=',$query_item);
					$query_item_name = $query_item_arr[0];
					if ($query_item_name!='') {			
						if (isset($query_item_arr[1]))
							$query_item_value = $query_item_arr[1];
						else 
							$query_item_value = '';
							
						if ($param_except!=$query_item_name)
							$query_parameters[$query_item_name] = $query_item_value;
					}
				}
			}
			return $query_parameters;
		}
		
		/**
         * Return the current page URL with query string
         *
         * @static
         * @param 	array	$param_except	is defined, exclude the parameters form the query string
         * @return 	string
         */
		static function get_current_url($param_except=array())
		{
			$to_return = 'http';
			
			if (isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"] == "on")
				$to_return .= "s";
			
			$to_return .= '://' . $_SERVER["SERVER_NAME"];
			
			if ($_SERVER["SERVER_PORT"] != "80")
				$to_return .=  ':' . $_SERVER["SERVER_PORT"];
			
			if (substr_count($_SERVER["REQUEST_URI"],'?')>0)
				$to_return .= substr($_SERVER["REQUEST_URI"], 0, strpos($_SERVER["REQUEST_URI"], '?'));
			else 
				$to_return .= $_SERVER["REQUEST_URI"];
			
			if (count($param_except)>0) {
				$query_parameters = array();
				$query_arr = explode('&',$_SERVER['QUERY_STRING']);
				foreach ($query_arr as $query_item) {
					$query_item_arr = explode('=',$query_item);
					$query_item_name = $query_item_arr[0];
					
					if (!in_array($query_item_name,$param_except))
						$query_parameters[] = join('=',$query_item_arr);
				}
				$query_parameters_str = join('&',$query_parameters);
			}
			else 
				$query_parameters_str = $_SERVER['QUERY_STRING'];
			
			if ($query_parameters_str!='')
				$to_return .= '?' . $query_parameters_str;
			
			return $to_return;
		}
        /**
         * Function to sort Array data
         *
         * @static 
         * @param array $array to be sorted
         * @param string $by key of the values to be to sort (the associative array name that is one level deep)
         * @param string $order can be "ASC" or "DESC"
         * @param string $type can be "num" or "str"
         * @return array
         */
        static function sortmddata($array, $by, $order, $type) {
			if (is_array($array)) {

				$sortby = "sort$by"; //This sets up what you are sorting by
				
				$firstval = current($array); //Pulls over the first array
				if (is_array($firstval)) {
					$vals = array_keys($firstval); //Grabs the associate Arrays
					
					foreach ($vals as $init) {
					   $keyname = "sort$init";
					   $$keyname = array();
					}
					//This was strange because I had problems adding
					//Multiple arrays into a variable variable
					//I got it to work by initializing the variable variables as arrays
					//Before I went any further
					foreach ($array as $key => $row) {
						foreach ($vals as $names) {
						   $keyname = "sort$names";
						   $test = array();
						   $test[$key] = @strtolower($row[$names]); // @ is for the case the value is an array, in this case we will ignore this
						   $$keyname = array_merge($$keyname,$test);
						   
						}
					}
			
					//This will create dynamic mini arrays so that I can perform
					//the array multisort with no problem
					//Notice the temp array... I had to do that because I 
					//cannot assign additional array elements to a 
					//varaiable variable            
					
					if ($order == "DESC") {  
						if ($type == "num"){
							array_multisort($$sortby,SORT_DESC, SORT_NUMERIC,$array);
						} 
						else {
							array_multisort($$sortby,SORT_DESC, SORT_STRING,$array);
						}
					}
					else {
						if ($type == "num"){
							array_multisort($$sortby,SORT_ASC, SORT_NUMERIC,$array);
						} 
						else {
							if ($$sortby!=NULL)
								array_multisort($$sortby,SORT_ASC, SORT_STRING,$array);
						}
					}
			
					//This just goed through and asks the additional arguments
					//What they are doing and are doing variations of
					//the multisort
					return $array;
				}
			}
			return array();
		}
	}
}
