<?php
if (!class_exists('WPContentMagic_Scheduling')) {
	class WPContentMagic_Scheduling
	{
		/**
		 * Add the scheduled posts content, based of the settings
		 * 
		 * @param	array	$posts	with title/content
		 * @param	array	$settings
		 * @return	int		the amount of Posts added
		 */
		static function add_scheduled_posts($posts,$settings) {
			/*
			 * Define general dates and interval
			 */
			
			if (count($posts)==0) {
				return array(0,0);
			}
			
			// Define when will be start
			$begin_dt = time(); // if ($settings['auto_posting_schedule']=='now')
			
			if ($settings['auto_posting_schedule']=='last_post') {
				// Start the imports from the last Post date
				global $wpdb;
				$result = $wpdb->get_var("select UNIX_TIMESTAMP(post_date) from $wpdb->posts 
											where post_status='publish' order by post_date DESC limit 1");
				if ($result) {
					$begin_dt = $result;
				}
			}
			elseif ($settings['auto_posting_schedule']=='custom') {
				// Start the imports from the specified Custom date, format mm/dd/yyyy hh:mm
				$begin_dt = strtotime($settings['custom_schedule_date']);
			}
			
			// Define intervals Min and Max, for example, random intervals between 2 minutes to 5 hours
			// Min
			$schedule_number_begin = (int) $settings['schedule_number_begin'];
			$schedule_unit_begin = $settings['schedule_unit_begin'];
			$interval_seconds_min = 0;
			if ($schedule_unit_begin=='minutes') {
				$interval_seconds_min = $schedule_number_begin * 60;
			}
			elseif ($schedule_unit_begin=='hours') {
				$interval_seconds_min = $schedule_number_begin * 60 * 60;
			}
			elseif ($schedule_unit_begin=='days') {
				$interval_seconds_min = $schedule_number_begin * 60 * 60 * 24;
			}
			// Max			
			$schedule_number_end = $settings['schedule_number_end'];
			$schedule_unit_end = $settings['schedule_unit_end'];
			$interval_seconds_max = 0;
			if ($schedule_unit_end=='minutes') {
				$interval_seconds_max = $schedule_number_end * 60;
			}
			elseif ($schedule_unit_end=='hours') {
				$interval_seconds_max = $schedule_number_end * 60 * 60;
			}
			elseif ($schedule_unit_end=='days') {
				$interval_seconds_max = $schedule_number_end * 60 * 60 * 24;
			}
			
			/*
			 * Add Posts or add Scheduled Posts to database
			 */
			$time_to_used = $begin_dt;
			$how_many_post = 0;
			foreach ($posts as $post_data) {
				$title = $post_data[0];
				$content = $post_data[1];
				
				// Add Post, if the time is future, will be scheduled
				WPContentMagic_WPPosts::add_post($title,$content,$time_to_used,$settings);
				$how_many_post++;
				
				// Define the next time to use
				$time_to_used += rand($interval_seconds_min,$interval_seconds_max);
			}
			
			return $how_many_post;
		}
	}
}
