<?php
/*
Plugin Name: WP Content Magic
Plugin URI: http://www.wpcontentmagic.com
Version: 1.2
Author: Scott Inman
Description: Automatically upload articles now, in the past, or in the future with SEO attributes!
*/

/**
 * Version of WordPress
 * @global	string	$wp_version
 */
global $wp_version;

$exit_msg = __('This plugin require WordPress 3.0.4 or newer','wp-content-magic')
			.'. <a href="http://codex.wordpress.org/Upgrading_WordPress">'.__('Please update','wp-content-magic')
			.'</a>';
if (version_compare($wp_version, "3.0.4", "<")) { 
	exit($exit_msg);
}

// Avoid name collisions.
if (!class_exists('WPContentMagic')) {
	class WPContentMagic
    {
       /**
	    * The url to the plugin
	    *
	    * @static 
	    * @var string
	    */
        static $plugin_url;
         
       /**
	    * The path to the plugin
	    *
	    * @static 
	    * @var string
	    */
        static $plugin_dir;
        
       /**
	    * The path to the plugin templates files
	    *
	    * @static 
	    * @var string
	    */
        static $template_dir;
        
       /**
	    * Translator domain
	    *
	    * @static 
	    * @var string
	    */
        static $trans_domain = 'wp-content-magic';
        
       /**
	    * The prefix for the plugin tables in database
	    *
	    * @static 
	    * @var string
	    */
        static $db_prefix;
        
       /**
         * Executes all initialization code for the plugin.
         * 
         * @return void
         * @access public
		 */
        function __construct() {
        	
        	// Define static values
        	self::$plugin_url = trailingslashit( WP_PLUGIN_URL.'/'. dirname( plugin_basename(__FILE__) ));
        	self::$plugin_dir = pathinfo(__FILE__,PATHINFO_DIRNAME);
        	self::$template_dir = self::$plugin_dir . '/templates';
        	self::$db_prefix = 'wp_content_magic_';
        	
        	// Include all classes
        	include(self::$plugin_dir . '/includes/all_classes.php');
        	
	        // Add Menu Box in Admin Panel
           	add_action('admin_menu', array(&$this, 'admin_menu'));
           	
           	// Used in all pages when a Post content is show
           	wp_enqueue_script( 'jquery' );
           	wp_enqueue_style('wp-content-magic-styles', self::$plugin_url . 'templates/css/styles.css');						
        }
        
        /** 
		 * Hooks the add of the main menu
		 * 
		 * @return void
		 * @access public
		 */
        function admin_menu() {
        	
        	add_menu_page(__('WP Content<br />Magic',WPContentMagic::$trans_domain), __('WP Content Magic',WPContentMagic::$trans_domain), 'manage_options', basename(__FILE__), array(&$this, 'handle_settings'), self::$plugin_url . '/templates/images/magic-icon.png');
			
        	$page_added_settings = add_submenu_page(basename(__FILE__), __('Settings',WPContentMagic::$trans_domain)
        				, __('Settings',WPContentMagic::$trans_domain)
        				, 'manage_options', basename(__FILE__), array(&$this, 'handle_settings'));
			
			$page_added_track_links = add_submenu_page(basename(__FILE__), __('Track Links',WPContentMagic::$trans_domain)
						, __('Track Links',WPContentMagic::$trans_domain)
						, 'manage_options', 'WPContentMagic-track-links', array(&$this, 'handle_track_links'));
			
			$page_added_stop_words = add_submenu_page(basename(__FILE__), __('Stop Words',WPContentMagic::$trans_domain)
						, __('Stop Words',WPContentMagic::$trans_domain)
						, 'manage_options', 'WPContentMagic-stop-words', array(&$this, 'handle_stop_words'));
						
			// Add relative JS scripts and CSS styles
			add_action( "admin_print_scripts-$page_added_settings", array(&$this, 'handle_settings_js_scripts') );
			add_action( "admin_print_styles-$page_added_settings", array(&$this, 'handle_settings_styles') );
			
			add_action( "admin_print_scripts-$page_added_track_links", array(&$this, 'handle_track_links_js_scripts') );
			add_action( "admin_print_styles-$page_added_track_links", array(&$this, 'handle_track_links_styles') );
        }
        
    	/** 
		 * Add CSS code
		 * 
		 * @return void
		 * @access public
		 */
        function handle_track_links_styles() {
        	wp_enqueue_style('wp-content-magic-jquery-ui-styles', self::$plugin_url . 'templates/js/lib/jquery-ui-1.8.9.custom/css/smoothness/jquery-ui-1.8.9.custom.css');
        	wp_enqueue_style('wp-content-magic-jqgrid-styles', self::$plugin_url . 'templates/js/lib/jquery.jqGrid-3.8.2/css/ui.jqgrid.css');
        }
        
    	/** 
		 * Add JS code
		 * 
		 * @return void
		 * @access public
		 */
        function handle_track_links_js_scripts() {
        	wp_enqueue_script('wp-content-magic-jquery-ui-script',  self::$plugin_url . 'templates/js/lib/jquery-ui-1.8.9.custom/jquery-ui-1.8.9.custom.min.js');
        	wp_enqueue_script('wp-content-magic-jqgrid-locale-script',  self::$plugin_url . 'templates/js/lib/jquery.jqGrid-3.8.2/js/i18n/grid.locale-en.js');
			wp_enqueue_script('wp-content-magic-jqgrid-script',  self::$plugin_url . 'templates/js/lib/jquery.jqGrid-3.8.2/js/jquery.jqGrid.min.js');
			
			wp_enqueue_script('wp-content-magic-track-links-script',  self::$plugin_url . 'templates/js/scripts/track-links.js');
			wp_localize_script( 
								'wp-content-magic-track-links-script'
								, 'WPContentMagic'
								, array(
								  	'plugin_url' => self::$plugin_url
								));
        }
        
    	/** 
		 * Add CSS code
		 * 
		 * @return void
		 * @access public
		 */
        function handle_settings_styles() {
        	wp_enqueue_style('wp-content-magic-jquery-ui-styles', self::$plugin_url . 'templates/js/lib/jquery-ui-1.8.9.custom/css/smoothness/jquery-ui-1.8.9.custom.css');
        }
        
    	/** 
		 * Add JS code
		 * 
		 * @return void
		 * @access public
		 */
        function handle_settings_js_scripts() {
        	wp_enqueue_script('wp-content-magic-jquery-ui-script',  self::$plugin_url . 'templates/js/lib/jquery-ui-1.8.9.custom/jquery-ui-1.8.9.custom.min.js');
        	wp_enqueue_script('wp-content-magic-timepicker-script',  self::$plugin_url . 'templates/js/lib/jquery-ui-timepicker-addon.js');
			wp_enqueue_script('wp-content-magic-settings',  self::$plugin_url . 'templates/js/scripts/settings.js');
        }
        
    	/**
		 * Handles the main menu for handle_stop_words
		 * 
		 * @return void
		 * @access public
		 */
        function handle_stop_words() {
           	include(self::$plugin_dir . '/includes/admin/handle_stop_words.php');
        }
        
    	/**
		 * Handles the main menu for handle_track_links
		 * 
		 * @return void
		 * @access public
		 */
        function handle_track_links() {
           	include(self::$plugin_dir . '/includes/admin/handle_track_links.php');
        }
        
    	/**
		 * Handles the main menu for handle_settings
		 * 
		 * @return void
		 * @access public
		 */
        function handle_settings() {
           	include(self::$plugin_dir . '/includes/admin/handle_settings.php');
        }
        
    	/**
         * 
         * Execute code in activation
         * 
         * @return 	void
         * @access 	public
         */
        function install() {
        	
        	// Creating tables
			include(self::$plugin_dir . '/db/tables.php');
		}
	}
}

// create new instance of the class
$WPContentMagic = new WPContentMagic();
if (isset($WPContentMagic)) {
    // register the activation-deactivation function by passing the reference to our instance
    register_activation_hook(__FILE__, array(&$WPContentMagic, 'install'));
}
